[![Documentation Status](https://readthedocs.org/projects/ansicolortags/badge/?version=latest)](https://cobind.readthedocs.io/en/latest/)
[![GitHub issues](https://img.shields.io/github/issues/liguowang/cobind)](https://github.com/liguowang/cobind/issues)
[![GitHub license](https://img.shields.io/github/license/liguowang/cobind)](https://github.com/liguowang/cobind/blob/main/LICENSE)

### Install cobind using [pip](https://pip.pypa.io/en/stable/)

 `$ pip install cobind`
 or 
 `$ pip install git+https://github.com/liguowang/cobind.git`
 
### Upgrade

 `$ pip install cobind --upgrade`

### Uninstall
 `pip -y uninstall cobind`

### Documentation

https://cobind.readthedocs.io/en/latest/
